https://gcc.gnu.org/bugzilla/show_bug.cgi?id=127644

Richard Biener <rguenth at gcc dot gnu.org> changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
             Status|UNCONFIRMED                 |NEW
     Ever confirmed|0                           |1
   Last reconfirmed|                            |2026-09-28

--- Comment #1 from Richard Biener <rguenth at gcc dot gnu.org> ---
Confirmed with -O2 (without -flto) on a Zen4 machine, 130s -> 141s

Reply via email to